@@ -524,12 +524,12 @@ impl Application {
         let mut transfer_pool = self.transfer_queue.create_command_pool()?;
         let transfer_buffer = transfer_pool.create_command_buffer(
             &[CommandBufferSemaphore::Timeline {
-                semaphore: &self.transfer_timeline,
+                semaphore: self.transfer_timeline.handle(),
                 stage: vk::PipelineStageFlags2KHR::NONE_KHR,
                 value: self.transfer_timeline_value,
             }],
             &[CommandBufferSemaphore::Timeline {
-                semaphore: &self.transfer_timeline,
+                semaphore: self.transfer_timeline.handle(),
                 stage: vk::PipelineStageFlags2KHR::NONE_KHR,
                 value: self.transfer_timeline_value + 1,
             }],
@@ -637,12 +637,12 @@ impl Application {
         let mut transfer_pool = self.transfer_queue.create_command_pool()?;
         let transfer_buffer = transfer_pool.create_command_buffer(
             &[CommandBufferSemaphore::Timeline {
-                semaphore: &self.transfer_timeline,
+                semaphore: self.transfer_timeline.handle(),
                 stage: vk::PipelineStageFlags2KHR::NONE_KHR,
                 value: self.transfer_timeline_value,
             }],
             &[CommandBufferSemaphore::Timeline {
-                semaphore: &self.transfer_timeline,
+                semaphore: self.transfer_timeline.handle(),
                 stage: vk::PipelineStageFlags2KHR::NONE_KHR,
                 value: self.transfer_timeline_value + 1,
             }],
@@ -676,7 +676,7 @@ impl Application {
         let graphics_buffer = self.graphics_command_pool.create_command_buffer(
             &[],
             &[CommandBufferSemaphore::Binary {
-                semaphore: &self.render_semaphore,
+                semaphore: self.render_semaphore.handle(),
                 stage: vk::PipelineStageFlags2KHR::COLOR_ATTACHMENT_OUTPUT_KHR,
             }],
         )?;
